/*------------------------------------------------------------------------
Module:        /extra/development/altermime-0.1.1/altermime.c
Author:        Paul L Daniels
Project:       AlterMime
State:         Development
Creation Date: 02/05/2001
Description:   Altermime is a program/object which will allow arbitary alterations to a given MIME encoded mailpack, such as disclaimer additions and attachment-nullification.
------------------------------------------------------------------------*/

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include "mime_alter.h"

/* Global DEFINES */
#define _VERSION "alterMIME v0.1.10\nby Paul L Daniels pldaniels@pldaniels.com\nhttp://pldaniels.com/altermime\n"
#define _USAGE "\
altermime --input=<input mime pack>\n\
	[--disclaimer=<disclaimer file>]\n\
	[--htmltoo]\n\
	[--remove=<remove file name>]\n\
	[--remove_prefix=<prefix>]\n\
	[--removeall]\n\
	[--replace=<filename to replace> --with=<replace with>]\n\
	[--xheader=\"...\"\n\
	[--altersigned]\n\
	[--verbose]\n\
	[--version]\n\n\
	"

/* Global variables / settings */
char _default_remove_prefix[]="removed";

char *_input_file=NULL;
char *_disclaimer_file=NULL;
char *_remove_filename=NULL;
char *_remove_prefix=_default_remove_prefix;
char *_replace=NULL;
char *_with=NULL;
char *_xheader=NULL;
int _verbose=0;

/*------------------------------------------------------------------------
Procedure:     parse_args ID:1
Purpose:       Parses the command line arguments and sets up internal parameters
Input:         argc: The number of arguments
argv: Array of strings
Output:        none
Errors:
------------------------------------------------------------------------*/
int parse_args( int argc, char **argv )
{
	int i;
	char *p=NULL;

	for (i = 1; i < argc; i++){
		if ((argv[i][0] == '-')&&(argv[i][1] == '-'))
		{
			p = argv[i];
			p += 2;

			if (strncmp(p,"input=",6)==0)
			{
				_input_file = p +strlen("input=");
			}
			else if (strncmp(p,"htmltoo",7)==0)
			{
				AM_set_HTMLtoo(1);
			}
			else if (strncmp(p,"disclaimer=",11)==0)
			{
				_disclaimer_file = p +strlen("disclaimer=");
			}
			else if (strncmp(p,"remove=",7)==0)
			{
				_remove_filename = p +strlen("remove=");
			}
			else if (strncmp(p, "remove_prefix=",13)==0)
			{
				_remove_prefix = p +strlen("remove_prefix=");
			}
			else if (strncmp(p, "removeall",9)==0)
			{
				AM_set_nullifyall(1);
				_remove_filename = p;
			}
			else if (strncmp(p, "altersigned",11)==0)
			{
				AM_set_altersigned(1);
			}
			else if (strncmp(p, "replace",7)==0)
			{
				_replace = p +strlen("replace=");
			}
			else if (strncmp(p, "with",4)==0)
			{
				_with = p +strlen("with=");
			}
			else if (strncmp(p, "xheader",7)==0)
			{
				_xheader = p +strlen("xheader=");
			}
			else if (strncmp(p, "version",7)==0)
			{
				fprintf(stdout,_VERSION);
				exit(0);
			}
			else if (strncmp(p, "verbose",7)==0)
			{
				_verbose=1;
			}
			else
			{
				fprintf(stderr,"Error, unknown parameter \"%s\"\n",p);
				fprintf(stderr,_USAGE);
				exit(1);
			} /* if-ELSE */
		} /* if argv == '--' */
	} /* for */

	return 0;
}



int main( int argc, char **argv )
{
	parse_args(argc, argv);

	if (!_input_file) {
		fprintf(stdout,"Error: No input file specified\n");
		fprintf(stdout,_USAGE);
		exit(1);
	}

	if (((!_replace)&&(_with))||((_replace)&&(!_with)))
	{
		fprintf(stderr,"Error: Both --replace= and --with= must be set\n");
		exit(1);
	}

	AM_set_verbose(_verbose);

	if ((_replace)&&(_with)) AM_attachment_replace( _input_file, _replace, _with, _with);
	if (_disclaimer_file) AM_add_disclaimer(_input_file, _disclaimer_file);
	if (_remove_filename) AM_nullify_attachment(_input_file, _remove_filename, _remove_prefix);
	if (_xheader) AM_insert_Xheader( _input_file, _xheader);

	return 0;
}

/*-------------------------------------------------END. */
