/* zstrncpy.c - Copy a specified number of bytes from string to string */

// 04/03/2002 - Corrected a 1-off situation where if the len was 1, the \0
// 	would be written to undefined space - my own fault on that one.


#include <stddef.h>
#include "zstrncpy.h"

/*------------------------------------------------------------------------
 Procedure:     zstrncpy ID:1
 Purpose:       Copy characters from 'src' to 'dst', writing not more than 'len'
                characters to the destination, including the terminating \0.
                Thus, for any effective copying, len must be > 1.
 Input:         char *dst: Destination string
                char *src: Source string
                size_t len: length of string
 Output:        Returns a pointer to the destination string.
 Errors:
------------------------------------------------------------------------*/
char *zstrncpy (char *dst, const char *src, size_t len)
{
	char *dp = dst;
	const char *sp = src;

	if (len == 0) return dst;

	// Compensate for the fact that we have to add a \0 at the end of our buffer
	// no matter WHAT!

	while ((len) && (*sp != '\0'))
	{
		*dp++ = *sp++;
		len--;
	}

	*dp = '\0';

	return dst;
}
